=== modified file 'DayView.qml'
--- DayView.qml	2014-03-26 14:39:17 +0000
+++ DayView.qml	2014-04-11 00:21:42 +0000
@@ -4,13 +4,15 @@
 import "dateExt.js" as DateExt
 import "ViewType.js" as ViewType
 
-Item{
+Page{
     id: root
     objectName: "DayView"
 
     property var currentDay: new Date()
     property bool isCurrentPage: false
 
+    Keys.forwardTo: [dayViewPath]
+
     Column {
         id: column
         anchors.top: parent.top

=== added file 'DeleteConfirmationDialog.qml'
--- DeleteConfirmationDialog.qml	1970-01-01 00:00:00 +0000
+++ DeleteConfirmationDialog.qml	2014-04-13 02:03:43 +0000
@@ -0,0 +1,43 @@
+import QtQuick 2.0
+import Ubuntu.Components 0.1
+import Ubuntu.Components.Popups 0.1
+
+Dialog {
+    id: dialogue
+
+    property var event;
+
+    signal deleteEvent(var eventId);
+
+    title: event.parentId ?
+               i18n.tr("Delete Recurring Event"):
+               i18n.tr("Delete Event") ;
+
+    text: event.parentId ?
+              i18n.tr('Delete only this event "'+event.displayLabel+'", or all events in the series?'):
+              i18n.tr('Are you sure you want to delete the event "'+ event.displayLabel +'"?');
+
+    Button {
+        text: i18n.tr("Delete series")
+        color: UbuntuColors.orange
+        onClicked: {
+            dialogue.deleteEvent(event.parentId);
+            PopupUtils.close(dialogue)
+        }
+        visible: event.parentId !== undefined
+    }
+
+    Button {
+        text: event.parentId ? i18n.tr("Delete this") : i18n.tr("Delete")
+        color: UbuntuColors.orange
+        onClicked: {
+            dialogue.deleteEvent(event.itemId);
+            PopupUtils.close(dialogue)
+        }
+    }
+
+    Button {
+        text: i18n.tr("Cancel")
+        onClicked: PopupUtils.close(dialogue)
+    }
+}

=== modified file 'EventDetails.qml'
--- EventDetails.qml	2014-04-05 06:31:50 +0000
+++ EventDetails.qml	2014-04-12 10:36:27 +0000
@@ -95,15 +95,27 @@
         }
     }
 
+    Keys.onEscapePressed: {
+        pageStack.pop();
+    }
+
+    Keys.onPressed: {
+        if ((event.key === Qt.Key_E) && ( event.modifiers & Qt.ControlModifier)) {
+            pageStack.push(Qt.resolvedUrl("NewEvent.qml"),{"event": root.event});
+        }
+    }
+
     tools: ToolbarItems {
-
         ToolbarButton {
             action:Action {
                 text: i18n.tr("Delete");
                 iconSource: "image://theme/delete,edit-delete-symbolic"
                 onTriggered: {
-                    model.removeItem(event);
-                    pageStack.pop();
+                    var dialog = PopupUtils.open(Qt.resolvedUrl("DeleteConfirmationDialog.qml"),root,{"event": event});
+                    dialog.deleteEvent.connect( function(eventId){
+                        model.removeItem(eventId);
+                        pageStack.pop();
+                    });
                 }
             }
         }
@@ -214,28 +226,31 @@
                 font.bold: true
             }
             //Guest Entery Model starts
-            ListView {
-                id:contactList
+            Column{
+                id: contactList
                 spacing: units.gu(1)
                 width: parent.width
-                height: units.gu((contactModel.count*4.5)+3)
                 clip: true
-                model: ListModel {
+                ListModel {
                     id: contactModel
                 }
-                delegate: Row{
-                    spacing: units.gu(1)
-                    CheckBox{
-                     checked: participationStatus
-                     enabled: false
-                    }
-                    Label {
-                        text:name
-                        anchors.verticalCenter:  parent.verticalCenter
-                        color: detailColor
+                Repeater{
+                    model: contactModel
+                    delegate: Row{
+                        spacing: units.gu(1)
+                        CheckBox{
+                            checked: participationStatus
+                            enabled: false
+                        }
+                        Label {
+                            text:name
+                            anchors.verticalCenter:  parent.verticalCenter
+                            color: detailColor
+                        }
                     }
                 }
             }
+
             //Guest Entries ends
             ThinDivider{}
             property int recurranceAreaMaxWidth: Math.max( recurrentHeader.headerWidth, reminderHeader.headerWidth) //Dynamic Height

=== modified file 'MonthComponent.qml'
--- MonthComponent.qml	2014-04-11 22:17:35 +0000
+++ MonthComponent.qml	2014-04-14 22:37:37 +0000
@@ -7,6 +7,8 @@
     id: root
     objectName: "MonthComponent"
 
+    property bool showEvents: false
+
     property var currentMonth;
     property var isYearView;
 
@@ -22,9 +24,29 @@
 
     height: ubuntuShape.height
 
+    Loader{
+        id: modelLoader
+        sourceComponent: showEvents ? modelComponent: undefined
+    }
+
+    Component{
+        id: modelComponent
+        EventListModel {
+            id: mainModel
+            startPeriod: intern.monthStart.midnight();
+            endPeriod: intern.monthStart.addDays((monthGrid.weekCount*7)-1).endOfDay()
+
+            onModelChanged: {
+                intern.eventStatus = Qt.binding(function() { return mainModel.containsItems(startPeriod,endPeriod,24*60*60)});
+            }
+        }
+    }
+
     QtObject{
         id: intern
 
+        property var eventStatus;
+
         property int curMonthDate: currentMonth.getDate()
         property int curMonth: currentMonth.getMonth()
         property int curMonthYear: currentMonth.getFullYear()
@@ -187,6 +209,19 @@
                 }
             }
 
+            Rectangle {
+                width: units.gu(1)
+                height: width
+                radius: height/2
+                color:"#5E2750"
+                visible: showEvents
+                         && intern.eventStatus !== undefined
+                         && intern.eventStatus[index] !== undefined
+                         &&intern.eventStatus[index]
+                anchors.top: dateLabel.bottom
+                anchors.horizontalCenter: dateLabel.horizontalCenter
+            }
+
             MouseArea {
                 anchors.fill: parent
                 onPressAndHold: {

=== modified file 'MonthView.qml'
--- MonthView.qml	2014-04-11 22:17:35 +0000
+++ MonthView.qml	2014-04-14 22:37:37 +0000
@@ -11,6 +11,8 @@
 
     signal dateSelected(var date);
 
+    Keys.forwardTo: [monthViewPath]
+
     PathViewBase{
         id: monthViewPath
 
@@ -44,6 +46,8 @@
         delegate: MonthComponent{
             property bool isCurrentItem: index === monthViewPath.currentIndex
 
+            showEvents: true
+
             width: parent.width - units.gu(5)
             height: parent.height - units.gu(5)
 

=== modified file 'NewEvent.qml'
--- NewEvent.qml	2014-04-05 04:49:47 +0000
+++ NewEvent.qml	2014-04-05 08:53:53 +0000
@@ -177,6 +177,10 @@
 
     title: isEdit ? i18n.tr("Edit Event"):i18n.tr("New Event")
 
+    Keys.onEscapePressed: {
+        pageStack.pop();
+    }
+
     tools: ToolbarItems {
         //keeping toolbar always open
         opened: true

=== modified file 'PathViewBase.qml'
--- PathViewBase.qml	2013-12-14 02:44:09 +0000
+++ PathViewBase.qml	2014-02-27 15:09:06 +0000
@@ -9,6 +9,9 @@
     signal nextItemHighlighted();
     signal previousItemHighlighted();
 
+    signal scrollUp();
+    signal scrollDown();
+
     preferredHighlightBegin: 0.5
     preferredHighlightEnd: 0.5
 
@@ -31,8 +34,29 @@
         return 1;
     }
 
+    Keys.onLeftPressed:{
+        root.decrementCurrentIndex();
+    }
+
+    Keys.onRightPressed:{
+        root.incrementCurrentIndex();
+    }
+
+    Keys.onSpacePressed: {
+        root.scrollDown();
+    }
+
+    Keys.onDownPressed: {
+        root.scrollDown();
+    }
+
+    Keys.onUpPressed: {
+        root.scrollUp();
+    }
+
     onCurrentIndexChanged: {
         var diff = currentIndex - intern.previousIndex
+        if(diff == 0) return;
 
         if (intern.previousIndex === count - 1 && currentIndex === 0) diff = 1
         if (intern.previousIndex === 0 && currentIndex === count - 1) diff = -1

=== modified file 'TimeLineBaseComponent.qml'
--- TimeLineBaseComponent.qml	2014-04-10 03:17:08 +0000
+++ TimeLineBaseComponent.qml	2014-04-14 22:37:37 +0000
@@ -15,13 +15,43 @@
 
     property int type: ViewType.ViewTypeWeek
 
+    //visible hour
+    property int scrollHour;
+
     function scrollToCurrentTime() {
         //scroll to current time
         var currentTime = new Date();
         //TODO: if current time is early morning should we show time from 9 am ?
-        var hour = currentTime.getHours();
-
-        timeLineView.contentY = hour * units.gu(10);
+        scrollHour = currentTime.getHours();
+
+        timeLineView.contentY = scrollHour * units.gu(10);
+        if(timeLineView.contentY >= timeLineView.contentHeight - timeLineView.height) {
+            timeLineView.contentY = timeLineView.contentHeight - timeLineView.height
+        }
+    }
+
+    Connections{
+        target: parent
+        onScrollUp:{
+            scrollHour--;
+            if( scrollHour < 0) {
+                scrollHour =0;
+            }
+            scrollToHour();
+        }
+
+        onScrollDown:{
+            scrollHour++;
+            var visibleHour = root.height / units.gu(10);
+            if( scrollHour > (25 -visibleHour)) {
+                scrollHour = 25 - visibleHour;
+            }
+            scrollToHour();
+        }
+    }
+
+    function scrollToHour() {
+        timeLineView.contentY = scrollHour * units.gu(10);
         if(timeLineView.contentY >= timeLineView.contentHeight - timeLineView.height) {
             timeLineView.contentY = timeLineView.contentHeight - timeLineView.height
         }

=== modified file 'TimeLineHeader.qml'
--- TimeLineHeader.qml	2014-03-26 19:06:27 +0000
+++ TimeLineHeader.qml	2014-04-12 04:02:41 +0000
@@ -45,33 +45,12 @@
         }
 
         function getStartDate() {
+            var indexType = header.indexType(index);
             switch(type) {
             case ViewType.ViewTypeWeek:
-                return getDateForWeek();
+                return date.addDays(7*indexType);
             case ViewType.ViewTypeDay:
-                return getDateForDay();
-            }
-        }
-
-        function getDateForDay() {
-            switch( header.indexType(index)) {
-            case 0:
-                return date;
-            case -1:
-                return date.addDays(-1);
-            case 1:
-                return date.addDays(1);
-            }
-        }
-
-        function getDateForWeek() {
-            switch( header.indexType(index)) {
-            case 0:
-                return date;
-            case -1:
-                return date.addDays(-7);
-            case 1:
-                return date.addDays(7);
+                return date.addDays(1*indexType);
             }
         }
     }

=== modified file 'WeekView.qml'
--- WeekView.qml	2014-04-05 04:57:34 +0000
+++ WeekView.qml	2014-04-11 00:21:42 +0000
@@ -4,101 +4,103 @@
 import "dateExt.js" as DateExt
 import "ViewType.js" as ViewType
 
-Column {
+Page{
     id: root
-    objectName: "WeekView"
-
     property var dayStart: new Date();
     property var firstDay: dayStart.weekStart(Qt.locale().firstDayOfWeek);
     property bool isCurrentPage: false
 
     signal dateSelected(var date);
 
-    anchors.fill: parent
-    anchors.top: parent.top
-    anchors.topMargin: units.gu(1.5)
-    spacing: units.gu(1)
-
-    ViewHeader{
-        id: viewHeader
-        month: dayStart.getMonth()
-        year: dayStart.getFullYear()
-    }
-
-    TimeLineHeader{
-        id: weekHeader
-        objectName: "weekHeader"
-        type: ViewType.ViewTypeWeek
-        date: firstDay
-
-        onDateSelected: {
-            root.dateSelected(date);
-        }
-    }
-
-    PathViewBase{
-        id: weekViewPath
-
-        width: parent.width
-        height: root.height - weekViewPath.y
-
-        //This is used to scroll all view together when currentItem scrolls
-        property var childContentY;
-
-        onNextItemHighlighted: {
-            nextWeek();
-            weekHeader.incrementCurrentIndex()
-        }
-
-        onPreviousItemHighlighted: {
-            previousWeek();
-            weekHeader.decrementCurrentIndex()
-        }
-
-        function nextWeek() {
-            dayStart = firstDay.addDays(7);
-        }
-
-        function previousWeek(){
-            dayStart = firstDay.addDays(-7);
-        }
-
-        delegate: TimeLineBaseComponent {
-            id: timeLineView
-
+    Keys.forwardTo: [weekViewPath]
+
+    Column {
+        objectName: "WeekView"
+
+        anchors.fill: parent
+        anchors.top: parent.top
+        anchors.topMargin: units.gu(1.5)
+        spacing: units.gu(1)
+
+        ViewHeader{
+            id: viewHeader
+            month: dayStart.getMonth()
+            year: dayStart.getFullYear()
+        }
+
+        TimeLineHeader{
+            id: weekHeader
+            objectName: "weekHeader"
             type: ViewType.ViewTypeWeek
+            date: firstDay
+
+            onDateSelected: {
+                root.dateSelected(date);
+            }
+        }
+
+        PathViewBase{
+            id: weekViewPath
 
             width: parent.width
-            height: parent.height
-
-            startDay: firstDay.addDays( weekViewPath.indexType(index) * 7)
-
-            Connections{
-                target: root
-                onIsCurrentPageChanged:{
-                    if(root.isCurrentPage){
-                        timeLineView.scrollToCurrentTime();
+            height: root.height - weekViewPath.y
+
+            //This is used to scroll all view together when currentItem scrolls
+            property var childContentY;
+
+            onNextItemHighlighted: {
+                nextWeek();
+                weekHeader.incrementCurrentIndex()
+            }
+
+            onPreviousItemHighlighted: {
+                previousWeek();
+                weekHeader.decrementCurrentIndex()
+            }
+
+            function nextWeek() {
+                dayStart = firstDay.addDays(7);
+            }
+
+            function previousWeek(){
+                dayStart = firstDay.addDays(-7);
+            }
+
+            delegate: TimeLineBaseComponent {
+                id: timeLineView
+
+                type: ViewType.ViewTypeWeek
+
+                width: parent.width
+                height: parent.height
+
+                startDay: firstDay.addDays( weekViewPath.indexType(index) * 7)
+
+                Connections{
+                    target: root
+                    onIsCurrentPageChanged:{
+                        if(root.isCurrentPage){
+                            timeLineView.scrollToCurrentTime();
+                        }
                     }
                 }
-            }
-
-            //get contentY value from PathView, if its not current Item
-            Binding{
-                target: timeLineView
-                property: "contentY"
-                value: weekViewPath.childContentY;
-                when: !timeLineView.PathView.isCurrentItem
-            }
-
-            //set PathView's contentY property, if its current item
-            Binding{
-                target: weekViewPath
-                property: "childContentY"
-                value: contentY
-                when: timeLineView.PathView.isCurrentItem
+
+                //get contentY value from PathView, if its not current Item
+                Binding{
+                    target: timeLineView
+                    property: "contentY"
+                    value: weekViewPath.childContentY;
+                    when: !timeLineView.PathView.isCurrentItem
+                }
+
+                //set PathView's contentY property, if its current item
+                Binding{
+                    target: weekViewPath
+                    property: "childContentY"
+                    value: contentY
+                    when: timeLineView.PathView.isCurrentItem
+                }
             }
         }
     }
 }
-
-

=== modified file 'YearView.qml'
--- YearView.qml	2014-04-11 22:17:35 +0000
+++ YearView.qml	2014-04-14 22:37:37 +0000
@@ -2,58 +2,98 @@
 import Ubuntu.Components 0.1
 
 import "dateExt.js" as DateExt
-
-PathViewBase {
+Page {
     id: yearViewPage
-    objectName: "YearView"
+
     property int currentYear: DateExt.today().getFullYear();
-
     signal monthSelected(var date);
 
-    anchors.fill: parent
-
-    onNextItemHighlighted: {
-        currentYear = currentYear + 1;
-    }
-
-    onPreviousItemHighlighted: {
-        currentYear = currentYear - 1;
-    }
-
-    delegate: GridView{
-        id: yearView
-        clip: true
-        focus: index === yearViewPage.currentIndex
-
-        property bool isCurrentItem: index == yearViewPage.currentIndex
-        property int year: (yearViewPage.currentYear + yearViewPage.indexType(index))
-
-        width: parent.width
-        height: parent.height
-        anchors.top: parent.top
-
-        readonly property int minCellWidth: units.gu(30)
-        cellWidth: Math.floor(Math.min.apply(Math, [3, 4].map(function(n)
+    Keys.forwardTo: [pathView]
+
+    PathViewBase {
+        id: pathView
+        objectName: "YearView"
+
+        anchors.fill: parent
+
+        onNextItemHighlighted: {
+            currentYear = currentYear + 1;
+        }
+
+        onPreviousItemHighlighted: {
+            currentYear = currentYear - 1;
+        }
+
+        delegate: GridView{
+            id: yearView
+            clip: true
+            focus: index == pathView.currentIndex
+
+            property int scrollMonth: 0;
+            property bool isCurrentItem: index == pathView.currentIndex
+            property int year: (yearViewPage.currentYear + pathView.indexType(index))
+
+            width: parent.width
+            height: parent.height
+            anchors.top: parent.top
+
+            readonly property int minCellWidth: units.gu(30)
+            cellWidth: Math.floor(Math.min.apply(Math, [3, 4].map(function(n)
             { return ((width / n >= minCellWidth) ? width / n : width / 2) })))
 
-        cellHeight: cellWidth * 1.4
-
-        model: 12 /* months in a year */
-        delegate: Item {
-            width: yearView.cellWidth
-            height: yearView.cellHeight
-
-            MonthComponent{
-                id: monthComponent
-                currentMonth: new Date(yearView.year, index, 1, 0, 0, 0, 0)
-                anchors.fill: parent
-                anchors.margins: units.gu(0.5)
-                isYearView: true
-
-                dayLabelFontSize: "x-small"
-                dateLabelFontSize: "medium"
-                monthLabelFontSize: "medium"
-                yearLabelFontSize: "small"
+            cellHeight: cellWidth * 1.4
+
+            model: 12 /* months in a year */
+
+            onYearChanged : {
+                scrollMonth=0;
+                yearView.positionViewAtIndex(scrollMonth,GridView.Beginning);
+            }
+
+            //scroll in case content height changed
+            onHeightChanged: {
+                scrollMonth=0;
+                yearView.positionViewAtIndex(scrollMonth,GridView.Beginning);
+            }
+
+
+            Connections{
+                target: pathView
+                onScrollUp:{
+                    scrollMonth -= 2;
+                    if(scrollMonth < 0) {
+                        scrollMonth = 0;
+                    }
+                    yearView.positionViewAtIndex(scrollMonth,GridView.Beginning);
+                }
+
+                onScrollDown:{
+                    scrollMonth += 2;
+                    var visibleMonths = yearView.height / cellHeight;
+                    if( scrollMonth >= (11 - visibleMonths)) {
+                        scrollMonth = (11 - visibleMonths);
+                    }
+                    yearView.positionViewAtIndex(scrollMonth,GridView.Beginning);
+                }
+            }
+
+            delegate: Item {
+                width: yearView.cellWidth
+                height: yearView.cellHeight
+
+                MonthComponent {
+                    id: monthComponent
+                    showEvents: false
+                    currentMonth: new Date(yearView.year,index,1,0,0,0,0)
+
+                    anchors.fill: parent
+                    anchors.margins: units.gu(0.5)
+
+                    dayLabelFontSize:"x-small"
+                    dateLabelFontSize: "medium"
+                    monthLabelFontSize: "medium"
+                    yearLabelFontSize: "small"
+                }
             }
         }
     }

=== modified file 'calendar.qml'
--- calendar.qml	2014-04-10 02:25:31 +0000
+++ calendar.qml	2014-04-14 22:37:37 +0000
@@ -52,6 +52,8 @@
 
     width: units.gu(100)
     height: units.gu(80)
+    focus: true
+    Keys.forwardTo: [pageStack.currentPage]
 
     headerColor: "#266249"
     backgroundColor: "#478158"
@@ -61,10 +63,27 @@
     PageStack {
         id: pageStack
 
-        Component.onCompleted: push(tabPage)
-
-        Page{
-            id: tabPage
+        Component.onCompleted: push(tabs)
+
+        // This is for wait that the app is load when newEvent is invoked by argument
+        Timer {
+            id: timer
+            interval: 200; running: false; repeat: false
+            onTriggered: {
+                tabs.newEvent();
+            }
+        }
+
+        EventListModel{
+            id: eventModel
+            //This model is just for newevent
+            //so we dont need any update
+            autoUpdate: false
+        }
+
+        Tabs{
+            id: tabs
+            Keys.forwardTo: [tabs.currentPage.item]
 
             property var currentDay: DateExt.today();
 
@@ -73,21 +92,6 @@
             property int starttime: -1;
             property int endtime: -1;
 
-            onCurrentDayChanged: {
-                if( yearView.currentYear !== currentDay.getFullYear() ) {
-                    yearView.currentYear = tabPage.currentDay.getFullYear();
-                }
-
-                if( monthView.currentMonth !== undefined && !monthView.currentMonth.isSameDay(currentDay))
-                    monthView.currentMonth = currentDay.midnight();
-
-                if( dayView.currentDay !== undefined && !dayView.currentDay.isSameDay(currentDay))
-                    dayView.currentDay = currentDay
-
-                if( weekView.dayStart !== undefined && !weekView.dayStart.isSameDay(currentDay))
-                    weekView.dayStart = currentDay
-            }
-
             function newEvent() {
                 var startDate = new Date();
                 var endDate = new Date();
@@ -123,13 +127,13 @@
                 var difference = endTime - startTime;
 
                 if (difference > month)
-                    return 0;   // Year view
+                    return yearTab.index;   // Year view
                 else if (difference > 7 * day)
-                    return 1;   // Month view}
+                    return monthTab.index;   // Month view}
                 else if (difference > day)
-                    return 2;   // Week view
+                    return weekTab.index;   // Week view
                 else
-                    return 3;   // Day view
+                    return dayTab.index;   // Day view
             }
 
             // This function parse the argument
@@ -151,14 +155,14 @@
                 // If an url has been set
                 if (args.defaultArgument.at(0)) {
                     parseArguments(args.defaultArgument.at(0))
-                    tabPage.currentDay = new Date()
+                    tabs.currentDay = new Date()
                     // If newevent has been called on startup
                     if (newevent) {
                         timer.running = true;
                     }
                     else if (starttime !== -1) { // If no newevent has been setted, but starttime
                         var startTime = parseInt(starttime);
-                        tabPage.currentDay = new Date(startTime);
+                        tabs.currentDay = new Date(startTime);
 
                         // If also endtime has been settend
                         if (endtime !== -1) {
@@ -181,24 +185,6 @@
                 }
             } // End of Component.onCompleted:
 
-            // This is for wait that the app is load when newEvent is invoked by argument
-            Timer {
-                id: timer
-                interval: 200;
-                running: false;
-                repeat: false
-                onTriggered: {
-                    tabPage.newEvent();
-                }
-            }
-
-            EventListModel{
-                id: eventModel
-                //This model is just for newevent
-                //so we dont need any update
-                autoUpdate: false
-            }
-
             ToolbarItems {
                 id: commonToolBar
 
@@ -208,7 +194,11 @@
                         iconSource: Qt.resolvedUrl("calendar-today.svg");
                         text: i18n.tr("Today");
                         onTriggered: {
-                            tabPage.currentDay = (new Date()).midnight();
+                            tabs.currentDay = (new Date()).midnight();
+                            if(yearViewLoader.item ) yearViewLoader.item.currentYear = tabs.currentDay.getFullYear();
+                            if(monthViewLoader.item ) monthViewLoader.item.currentMonth = tabs.currentDay.midnight();
+                            if(weekViewLoader.item ) weekViewLoader.item.dayStart = tabs.currentDay;
+                            if(dayViewLoader.item ) dayViewLoader.item.currentDay = tabs.currentDay;
                         }
                     }
                 }
@@ -218,91 +208,157 @@
                         iconSource: Qt.resolvedUrl("new-event.svg");
                         text: i18n.tr("New Event");
                         onTriggered: {
-                            pageStack.push(Qt.resolvedUrl("NewEvent.qml"),{"date":tabPage.currentDay,"model":eventModel});
-                        }
-                    }
-                }
-            }
-
-            Tabs{
-                id: tabs
-
-                Tab{
-                    objectName: "yearTab"
-                    title: i18n.tr("Year")
-                    page: Page{
-                        objectName: "yearPage"
-                        anchors.fill: parent
-                        tools: commonToolBar
-                        YearView{
-                            id: yearView
-                            onMonthSelected: {
-                                tabs.selectedTabIndex = 1
-                                var now = DateExt.today();
-                                if( date.getMonth() === now.getMonth()
-                                        && date.getFullYear() === now.getFullYear()) {
-                                    monthView.currentMonth = now
-                                } else {
-                                    monthView.currentMonth = date.midnight();
-                                }
-                            }
-                        }
-                    }
-                }
-                Tab {
-                    id: monthTab
-                    objectName: "monthTab"
-                    title: i18n.tr("Month")
-                    page: MonthView{
-                        anchors.fill: parent
-                        tools: commonToolBar
-                        id: monthView
-
-                        onDateSelected: {
-                            tabs.selectedTabIndex  = 3
-                            tabPage.currentDay = date;
-                        }
-                    }
-                }
-                Tab{
-                    id: weekTab
-                    objectName: "weekTab"
-                    title: i18n.tr("Week")
-                    page: Page{
-                        anchors.fill: parent
-                        tools: commonToolBar
-                        WeekView{
-                            id: weekView
-                            anchors.fill: parent
-                            isCurrentPage: tabs.selectedTab == weekTab
-
-                            onDayStartChanged: {
-                                tabPage.currentDay = dayStart;
-                            }
-
-                            onDateSelected: {
-                                tabs.selectedTabIndex = 3;
-                                tabPage.currentDay = date;
-                            }
-                        }
-                    }
-                }
-
-                Tab{
-                    id: dayTab
-                    objectName: "dayTab"
-                    title: i18n.tr("Day")
-                    page: Page{
-                        anchors.fill: parent
-                        tools: commonToolBar
-                        DayView{
-                            id: dayView
-                            anchors.fill: parent
-                            isCurrentPage: tabs.selectedTab == dayTab
-
-                            onCurrentDayChanged: {
-                                tabPage.currentDay = currentDay;
-                            }
+                            pageStack.push(Qt.resolvedUrl("NewEvent.qml"),{"date":tabs.currentDay,"model":eventModel});
+                        }
+                    }
+                }
+            }
+
+            Keys.onTabPressed: {
+                if( event.modifiers & Qt.ControlModifier) {
+                    var currentTab = tabs.selectedTabIndex;
+                    currentTab ++;
+                    if( currentTab >= tabs.tabChildren.length){
+                        currentTab = 0;
+                    }
+                    tabs.selectedTabIndex = currentTab;
+                }
+            }
+
+            Keys.onBacktabPressed: {
+                if( event.modifiers & Qt.ControlModifier) {
+                    var currentTab = tabs.selectedTabIndex;
+                    currentTab --;
+                    if( currentTab < 0){
+                        currentTab = tabs.tabChildren.length -1;
+                    }
+                    tabs.selectedTabIndex = currentTab;
+                }
+            }
+
+            Tab{
+                id: yearTab
+                objectName: "yearTab"
+                title: i18n.tr("Year")
+                page: Loader{
+                    id: yearViewLoader
+                    objectName: "yearViewLoader"
+                    source: tabs.selectedTab == yearTab ? Qt.resolvedUrl("YearView.qml"):""
+                    onLoaded: {
+                        item.tools = Qt.binding(function() { return commonToolBar })
+                        item.currentYear = tabs.currentDay.getFullYear();
+                    }
+
+                    anchors{
+                        left: parent.left
+                        right: parent.right
+                        bottom: parent.bottom
+                    }
+
+                    Connections{
+                        target: yearViewLoader.item
+                        onMonthSelected: {
+                            var now = DateExt.today();
+                            if( date.getMonth() === now.getMonth()
+                                    && date.getFullYear() === now.getFullYear()) {
+                                tabs.currentDay = now;
+                            } else {
+                                tabs.currentDay = date.midnight();
+                            }
+                            tabs.selectedTabIndex = monthTab.index;
+                        }
+                    }
+                }
+            }
+
+            Tab{
+                id: monthTab
+                objectName: "monthTab"
+                title: i18n.tr("Month")
+                page: Loader{
+                    id: monthViewLoader
+                    objectName: "monthViewLoader"
+                    source: tabs.selectedTab == monthTab ? Qt.resolvedUrl("MonthView.qml"):""
+                    onLoaded: {
+                        item.tools = Qt.binding(function() { return commonToolBar })
+                        item.currentMonth = tabs.currentDay.midnight();
+                        print("onLoaded:"+ tabs.currentDay);
+                    }
+
+                    anchors{
+                        left: parent.left
+                        right: parent.right
+                        bottom: parent.bottom
+                    }
+
+                    Connections{
+                        target: monthViewLoader.item
+                        onDateSelected: {
+                            tabs.currentDay = date;
+                            tabs.selectedTabIndex = dayTab.index;
+                        }
+                    }
+                }
+            }
+
+            Tab{
+                id: weekTab
+                objectName: "weekTab"
+                title: i18n.tr("Week")
+                page: Loader{
+                    id: weekViewLoader
+                    objectName: "weekViewLoader"
+                    source: tabs.selectedTab == weekTab ? Qt.resolvedUrl("WeekView.qml"):""
+                    onLoaded: {
+                        item.tools = Qt.binding(function() { return commonToolBar })
+                        item.isCurrentPage= Qt.binding(function() { return tabs.selectedTab == weekTab })
+                        item.dayStart = tabs.currentDay;
+                    }
+
+                    anchors{
+                        left: parent.left
+                        right: parent.right
+                        bottom: parent.bottom
+                    }
+
+                    Connections{
+                        target: weekViewLoader.item
+                        onDayStartChanged: {
+                            tabs.currentDay = weekViewLoader.item.dayStart;
+                        }
+
+                        onDateSelected: {
+                            tabs.currentDay = date;
+                            tabs.selectedTabIndex = dayTab.index;
+                        }
+                    }
+                }
+            }
+
+            Tab{
+                id: dayTab
+                objectName: "dayTab"
+                title: i18n.tr("Day")
+                page: Loader{
+                    id: dayViewLoader
+                    objectName: "dayViewLoader"
+                    source: tabs.selectedTab == dayTab ? Qt.resolvedUrl("DayView.qml"):""
+                    onLoaded: {
+                        item.tools = Qt.binding(function() { return commonToolBar })
+                        item.isCurrentPage= Qt.binding(function() { return tabs.selectedTab == dayTab })
+                        item.currentDay = tabs.currentDay;
+                    }
+
+                    anchors{
+                        left: parent.left
+                        right: parent.right
+                        bottom: parent.bottom
+                    }
+
+                    Connections{
+                        target: dayViewLoader.item
+                        onCurrentDayChanged: {
+                            tabs.currentDay = dayViewLoader.item.currentDay;
                         }
                     }
                 }

=== modified file 'po/fa.po'
--- po/fa.po	2014-04-02 06:45:37 +0000
+++ po/fa.po	2014-04-12 09:42:31 +0000
@@ -8,41 +8,41 @@
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
 "POT-Creation-Date: 2014-03-10 19:02-0500\n"
-"PO-Revision-Date: 2013-09-08 12:03+0000\n"
-"Last-Translator: MohamadReza Mirdamadi <Unknown>\n"
+"PO-Revision-Date: 2014-04-11 15:16+0000\n"
+"Last-Translator: Danial Behzadi <dani.behzi@gmail.com>\n"
 "Language-Team: Persian <fa@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-02 06:45+0000\n"
-"X-Generator: Launchpad (build 16967)\n"
+"X-Launchpad-Export-Date: 2014-04-12 09:42+0000\n"
+"X-Generator: Launchpad (build 16976)\n"
 
 #: ../AllDayEventComponent.qml:101
 #, c-format, qt-format
 msgid "%1E"
-msgstr ""
+msgstr "%1E"
 
 #: ../AllDayEventComponent.qml:104
 #, qt-format
 msgid "%1 All day events"
-msgstr ""
+msgstr "%1 رویداد تمام‌روز"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../EventBubble.qml:36 ../EventDetails.qml:40
 msgid "hh:mm"
-msgstr ""
+msgstr "hh:mm"
 
 #. TRANSLATORS: the first argument (%1) refers to a start time for an event,
 #. while the second one (%2) refers to the end time
 #: ../EventBubble.qml:41
 #, qt-format
 msgid "%1 - %2"
-msgstr ""
+msgstr "%1 تا %2"
 
 #: ../EventDetails.qml:98
 msgid "Delete"
-msgstr ""
+msgstr "حذف"
 
 #: ../EventDetails.qml:110
 msgid "Edit"
@@ -50,31 +50,31 @@
 
 #: ../EventDetails.qml:140 ../NewEvent.qml:262
 msgid "Start"
-msgstr ""
+msgstr "آغاز"
 
 #: ../EventDetails.qml:145 ../NewEvent.qml:287
 msgid "End"
-msgstr ""
+msgstr "پایان"
 
 #: ../EventDetails.qml:153 ../NewEvent.qml:316
 msgid "All Day event:"
-msgstr ""
+msgstr "رویداد تمام‌روز:"
 
 #: ../EventDetails.qml:183 ../NewEvent.qml:365
 msgid "Location"
-msgstr ""
+msgstr "مکان"
 
 #: ../EventDetails.qml:207 ../NewEvent.qml:372
 msgid "Guests"
-msgstr ""
+msgstr "مهمان‌ها"
 
 #: ../EventDetails.qml:238 ../NewEvent.qml:381
 msgid "This happens"
-msgstr ""
+msgstr "رخ می‌دهد"
 
 #: ../EventDetails.qml:244 ../NewEvent.qml:398
 msgid "Remind me"
-msgstr ""
+msgstr "یادآوری کن"
 
 #: ../NewEvent.qml:106
 msgid "End time can't be before start time"
@@ -82,7 +82,7 @@
 
 #: ../NewEvent.qml:165
 msgid "Edit Event"
-msgstr ""
+msgstr "ویرایش رویداد"
 
 #: ../NewEvent.qml:165 ../calendar.qml:226
 msgid "New Event"
@@ -102,25 +102,25 @@
 
 #: ../NewEvent.qml:202
 msgid "Ok"
-msgstr ""
+msgstr "قبول"
 
 #: ../NewEvent.qml:247
 msgid "Date"
-msgstr ""
+msgstr "تاریخ"
 
 #: ../NewEvent.qml:334
 msgid "Event Name"
-msgstr ""
+msgstr "نام رویداد"
 
 #: ../NewEvent.qml:350
 msgid "Description"
-msgstr ""
+msgstr "توضیحات"
 
 #. TRANSLATORS: this is a time formatting string,
 #. see http://qt-project.org/doc/qt-5.0/qtqml/qml-qtquick2-date.html#details for valid expressions
 #: ../TimeLineBackground.qml:18
 msgid "hh ap"
-msgstr ""
+msgstr "hh ap"
 
 #: ../TimePicker.qml:23
 msgid "Time"
@@ -143,6 +143,9 @@
 "Calendar app accept three arguments: --starttime, --endtime and --newevet. "
 "They will be managed by system. See the source for a full comment about them"
 msgstr ""
+"برنامه‌ی تقویم سه آرگومان می پذیرد:starttime، endtime و newevet. این‌ها به "
+"وسیله‌ی سامانه مدیریت می شوند. برای دیدن توضیحات کامل در این باره، کد مبداُ "
+"را ببینید"
 
 #: ../calendar.qml:216
 msgid "Today"

=== modified file 'po/fi.po'
--- po/fi.po	2014-04-06 06:53:39 +0000
+++ po/fi.po	2014-04-14 06:00:12 +0000
@@ -8,13 +8,13 @@
 "Project-Id-Version: ubuntu-calendar-app\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
 "POT-Creation-Date: 2014-03-10 19:02-0500\n"
-"PO-Revision-Date: 2014-04-05 09:57+0000\n"
+"PO-Revision-Date: 2014-04-13 16:00+0000\n"
 "Last-Translator: Jiri Grönroos <Unknown>\n"
 "Language-Team: Finnish <fi@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2014-04-06 06:53+0000\n"
+"X-Launchpad-Export-Date: 2014-04-14 06:00+0000\n"
 "X-Generator: Launchpad (build 16976)\n"
 
 #: ../AllDayEventComponent.qml:101
@@ -74,7 +74,7 @@
 
 #: ../EventDetails.qml:244 ../NewEvent.qml:398
 msgid "Remind me"
-msgstr ""
+msgstr "Muistuta minua"
 
 #: ../NewEvent.qml:106
 msgid "End time can't be before start time"

=== modified file 'tests/autopilot/calendar_app/tests/test_calendar.py'
--- tests/autopilot/calendar_app/tests/test_calendar.py	2014-03-20 03:02:48 +0000
+++ tests/autopilot/calendar_app/tests/test_calendar.py	2014-04-12 04:06:45 +0000
@@ -92,5 +92,6 @@
 
         #verify that the event has been created in timeline
         self.main_view.open_toolbar().click_button("todaybutton")
+        self.main_view.switch_to_tab("dayTab")
         self.assertThat(self.main_view.get_num_events,
                         Eventually(NotEquals(num_events)))

